@@ -42,4 +42,7 @@ ALTER EXTENSION pg_hint_plan UPDATE TO "1.6.0";
 \dx+ pg_hint_plan
 ALTER EXTENSION pg_hint_plan UPDATE TO "1.6.1";
 \dx+ pg_hint_plan
+ALTER EXTENSION pg_hint_plan UPDATE TO "1.7.0";
+\dx+ pg_hint_plan
+\d hint_plan.hints
 DROP EXTENSION pg_hint_plan;
