@@ -21,7 +21,8 @@ my %defs =
 				 'build_child_join_sjinfo',
 				 'get_matching_part_pairs',
 				 'compute_partition_bounds',
-				 'try_partitionwise_join'],
+				 'try_partitionwise_join',
+				 'free_child_join_sjinfo'],
 	   head => core_c_head()},
    'make_join_rel.c'
    => {protos => [],
@@ -164,7 +165,7 @@ sub core_c_head()
  *     compute_partition_bounds()
  *     try_partitionwise_join()
  *
- * Portions Copyright (c) 1996-2023, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *-------------------------------------------------------------------------
@@ -193,8 +194,8 @@ sub make_join_rel_head
  *     make_join_rel()
  *     populate_joinrel_with_paths()
  *
- * Portions Copyright (c) 2013-2023, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
- * Portions Copyright (c) 1996-2023, PostgreSQL Global Development Group
+ * Portions Copyright (c) 2013-2024, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+ * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *-------------------------------------------------------------------------
